==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/crabshow/dialogs_nl.lua <==

dialogId("sec-v-ven0", "font_big", "I am trapped here.")
dialogStr("Ik zit hier opgesloten.")


dialogId("sec-v-ven1", "font_big", "I want to get out.")
dialogStr("Ik wil hier uit.")


dialogId("sec-v-ven2", "font_big", "How I can get out of here?")
dialogStr("Hoe komt ik hier uit?")


dialogId("sec-m-ven0", "font_small", "See, now you got out.")
dialogStr("Kijk, nu ben je eruit.")


dialogId("sec-m-ven1", "font_small", "So, we are together again.")
dialogStr("Zo, we zijn weer samen.")


dialogId("sec-v-zavreny", "font_big", "I am closed in a room without doors!")
dialogStr("Ik zit in een kamer zonder deuren!")


dialogId("sec-m-kamen", "font_small", "Try to loosen some stone in the wall.")
dialogStr("Probeer een steen uit de muur los te krijgen.")


dialogId("sec-m-krab", "font_small", "Isn`t that crab a little bit strange?")
dialogStr("Is die krab niet een beetje vreemd?")


dialogId("sec-v-ktery", "font_big", "Which one do you mean?")
dialogStr("Welke bedoel je?")


dialogId("sec-m-dole0", "font_small", "The upper one, of course.")
dialogStr("De bovenste, natuurlijk.")


dialogId("sec-m-dole1", "font_small", "The lower one, of course.")
dialogStr("De onderste, natuurlijk.")


dialogId("sec-v-normalni0", "font_big", "I think it`s normal.")
dialogStr("Die lijkt me volkomen normaal.")


dialogId("sec-v-normalni1", "font_big", "Yes, it`s a little weird.")
dialogStr("Ja, die is een beetje raar.")


dialogId("sec-m-balonky", "font_small", "We should be glad we have all these balls.")
dialogStr("Gelukkig hebben we zo veel ballen.")


dialogId("sec-v-mesto", "font_big", "This city looks suspiciously well preserved...")
dialogStr("Deze stad ziet er verdacht goed bewaard uit...")


dialogId("sec-v-pocit", "font_big", "I have a feeling that I am missing something.")
dialogStr("Ik het gevoeld dat ik iets over het hoofd zie.")


dialogId("sec-m-pocity", "font_small", "Your feelings... think about how to get us out.")
dialogStr("Jij en je gevoel ook altijd... bedenk liever een manier om hier uit te komen.")


dialogId("sec-v-pockej", "font_big", "No, wait, watch all these crabs for a moment... look into their eyes...")
dialogStr("Nee, wacht, let eens goed op deze krabben... kijk naar hun ogen...")


dialogId("sec-v-oci", "font_big", "Their eyes move in accord with each other. As if they are controlled by some common superconsciousness.")
dialogStr("Hun ogen bewegen steeds op dezelfde manier. Het lijkt wel alsof ze door een groter gemeenschappelijk bewustzijn worden bestuurd.")


dialogId("sec-m-program", "font_small", "But of course, they are controlled by computer program. Just like the undulating of water and your silly talk.")
dialogStr("Natuurlijk, ze worden door een computer programma bestuurd. Net als de golven in het water en jouw geklets.")


dialogId("sec-v-socha", "font_big", "Did we ever see a sculpture that would be silent for so long?")
dialogStr("Heb je ooit een beeld gezien dat zo lang stil bleef?")


dialogId("sec-m-situace", "font_small", "I think it`s only waiting for the best opportunity.")
dialogStr("Ik vrees dat het alleen maar wacht op een goede gelegenheid.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/crabshow/dialogs_nl.lua <==

dialogId("sec-v-ven0", "font_big", "I am trapped here.")
dialogStr("Ik zit hier opgesloten.")


dialogId("sec-v-ven1", "font_big", "I want to get out.")
dialogStr("Ik wil hier uit.")


dialogId("sec-v-ven2", "font_big", "How I can get out of here?")
dialogStr("Hoe komt ik hier uit?")


dialogId("sec-m-ven0", "font_small", "See, now you got out.")
dialogStr("Kijk, nu ben je eruit.")


dialogId("sec-m-ven1", "font_small", "So, we are together again.")
dialogStr("Zo, we zijn weer bij elkaar.")


dialogId("sec-v-zavreny", "font_big", "I am closed in a room without doors!")
dialogStr("Ik zit in een kamer zonder deuren!")


dialogId("sec-m-kamen", "font_small", "Try to loosen some stone in the wall.")
dialogStr("Probeer een steen uit de muur los te krijgen.")


dialogId("sec-m-krab", "font_small", "Isn’t that crab a little bit strange?")
dialogStr("Is die krab niet een beetje raar?")


dialogId("sec-v-ktery", "font_big", "Which one do you mean?")
dialogStr("Welke bedoel je?")


dialogId("sec-m-dole0", "font_small", "The upper one, of course.")
dialogStr("De bovenste, natuurlijk.")


dialogId("sec-m-dole1", "font_small", "The lower one, of course.")
dialogStr("De onderste, natuurlijk.")


dialogId("sec-v-normalni0", "font_big", "I think it’s normal.")
dialogStr("Die lijkt me volkomen normaal.")


dialogId("sec-v-normalni1", "font_big", "Yes, it’s a little weird.")
dialogStr("Ja, die is een beetje vreemd.")


dialogId("sec-m-balonky", "font_small", "We should be glad we have all these balls.")
dialogStr("Gelukkig hebben we veel van die ballen.")


dialogId("sec-v-mesto", "font_big", "This city looks suspiciously well preserved...")
dialogStr("Deze stad ziet er verdacht goed bewaard uit...")


dialogId("sec-v-pocit", "font_big", "I have a feeling that I am missing something.")
dialogStr("Ik heb het gevoel dat ik iets over het hoofd zie.")


dialogId("sec-m-pocity", "font_small", "Your feelings... think about how to get us out.")
dialogStr("Jij en je gevoel ook altijd... bedenk liever een manier om hier uit te komen.")


dialogId("sec-v-pockej", "font_big", "No, wait, watch all these crabs for a moment... look into their eyes...")
dialogStr("Nee, wacht, let eens goed op deze krabben... kijk naar hun ogen...")


dialogId("sec-v-oci", "font_big", "Their eyes move in accord with each other. As if they are controlled by some common superconsciousness.")
dialogStr("Hun ogen bewegen steeds op dezelfde manier. Het lijkt wel alsof ze door een groter gemeenschappelijk bewustzijn worden bestuurd.")


dialogId("sec-m-program", "font_small", "But of course, they are controlled by computer program. Just like the undulating of water and your silly talk.")
dialogStr("Natuurlijk, ze worden door een computer programma bestuurd. Net als de golven in het water en jouw geklets.")


dialogId("sec-v-socha", "font_big", "Did we ever see a sculpture that would be silent for so long?")
dialogStr("Heb je ooit een beeld gezien dat zo lang stil bleef?")


dialogId("sec-m-situace", "font_small", "I think it’s only waiting for the best opportunity.")
dialogStr("Ik ben bang dat het alleen maar wacht op een goede gelegenheid.")
